A module to contain traits and structs that are needed by the rest of the git-bot-feedback crate’s API.
Structs
- Github
ApiClient github - A structure to work with Github REST API.
- Local
Client - A (mostly) non-operational implementation of
RestApiClient. - Rest
ApiRate Limit Headers - A structure to contain the different forms of headers that describe a REST API’s rate limit status.
Statics
- USER_
AGENT - The User-Agent header value included in all HTTP requests.
Traits
- Rest
ApiClient - A custom trait that templates necessary functionality with a Git server’s REST API.
Functions
- init_
client - Instantiate an implementation of
RestApiClientbased on the environment.