pub struct LocalClient;Expand description
A (mostly) non-operational implementation of RestApiClient.
This is primarily meant for use in local contexts (or in unsupported CI platforms/contexts) because the following methods silently do nothing:
However, Self::get_list_of_changed_files does use the git CLI
to get a list of changed files.
Instantiate with Default::default().
use git_bot_feedback::client::LocalClient;
let client = LocalClient::default();Trait Implementations
Sourceimpl Clone for LocalClient
impl Clone for LocalClient
Sourcefn clone(&self) -> LocalClient
fn clone(&self) -> LocalClient
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalClient
impl Debug for LocalClient
Sourceimpl Default for LocalClient
impl Default for LocalClient
Sourcefn default() -> LocalClient
fn default() -> LocalClient
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for LocalClient
impl PartialEq for LocalClient
Sourceimpl RestApiClient for LocalClient
impl RestApiClient for LocalClient
Sourcefn get_list_of_changed_files<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
file_filter: &'life1 FileFilter,
lines_changed_only: &'life2 LinesChangedOnly,
base_diff: Option<String>,
ignore_index: bool,
) -> Pin<Box<dyn Future<Output = Result<HashMap<String, FileDiffLines>, ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn get_list_of_changed_files<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
file_filter: &'life1 FileFilter,
lines_changed_only: &'life2 LinesChangedOnly,
base_diff: Option<String>,
ignore_index: bool,
) -> Pin<Box<dyn Future<Output = Result<HashMap<String, FileDiffLines>, ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Available on crate feature
file-changes only.A way to get the list of changed files in the context of the CI event. Read more
Sourcefn is_pr_event(&self) -> bool
fn is_pr_event(&self) -> bool
Is the current CI event trigger a Pull Request? Read more
Sourcefn set_user_agent(&mut self, _user_agent: &str) -> Result<(), ClientError>
fn set_user_agent(&mut self, _user_agent: &str) -> Result<(), ClientError>
Set the user agent for the underlying HTTP request client. Read more
Sourcefn post_thread_comment<'life0, 'async_trait>(
&'life0 self,
_options: ThreadCommentOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn post_thread_comment<'life0, 'async_trait>(
&'life0 self,
_options: ThreadCommentOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
A way to post feedback to the Git server’s GUI. Read more
Sourcefn cull_pr_reviews<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_options: &'life1 mut ReviewOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn cull_pr_reviews<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_options: &'life1 mut ReviewOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Resolve outdated PR review comments and remove duplicate/reused comments. Read more
Sourcefn post_pr_review<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_options: &'life1 ReviewOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn post_pr_review<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_options: &'life1 ReviewOptions,
) -> Pin<Box<dyn Future<Output = Result<(), ClientError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Post a PR review based on the given options. Read more
Sourcefn write_output_variables(
&self,
vars: &[OutputVariable],
) -> Result<(), ClientError>
fn write_output_variables( &self, vars: &[OutputVariable], ) -> Result<(), ClientError>
Sets the given
vars as output variables. Read moreSourcefn start_log_group(&self, name: &str)
fn start_log_group(&self, name: &str)
This prints a line to indicate the beginning of a related group of log statements.
Sourcefn end_log_group(&self, name: &str)
fn end_log_group(&self, name: &str)
This prints a line to indicate the ending of a related group of log statements.
Sourcefn is_debug_enabled(&self) -> bool
fn is_debug_enabled(&self) -> bool
Is debug mode enabled? Read more
Sourcefn append_step_summary(&self, comment: &str) -> Result<(), RestClientError>
fn append_step_summary(&self, comment: &str) -> Result<(), RestClientError>
Appends a given comment to the CI workflow’s summary page. Read more
Sourcefn write_file_annotations(
&self,
annotations: &[FileAnnotation],
) -> Result<(), RestClientError>
fn write_file_annotations( &self, annotations: &[FileAnnotation], ) -> Result<(), RestClientError>
Sets the given
annotations as file annotations. Read moreSourcefn make_api_request(
&self,
client: &Client,
url: Url,
method: Method,
data: Option<String>,
headers: Option<HeaderMap>,
) -> Result<Request, RestClientError>
fn make_api_request( &self, client: &Client, url: Url, method: Method, data: Option<String>, headers: Option<HeaderMap>, ) -> Result<Request, RestClientError>
Construct a HTTP request to be sent. Read more
Sourcefn send_api_request<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
client: &'life1 Client,
request: Request,
rate_limit_headers: &'life2 RestApiRateLimitHeaders,
) -> Pin<Box<dyn Future<Output = Result<Response, RestClientError>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn send_api_request<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
client: &'life1 Client,
request: Request,
rate_limit_headers: &'life2 RestApiRateLimitHeaders,
) -> Pin<Box<dyn Future<Output = Result<Response, RestClientError>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
A convenience function to send HTTP requests and respect a REST API rate limits. Read more
Sourcefn try_next_page(&self, headers: &HeaderMap) -> Option<Url>
fn try_next_page(&self, headers: &HeaderMap) -> Option<Url>
Gets the URL for the next page from the headers in a paginated response. Read more
Sourcefn log_response<'life0, 'life1, 'async_trait>(
&'life0 self,
response: Response,
context: &'life1 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn log_response<'life0, 'life1, 'async_trait>(
&'life0 self,
response: Response,
context: &'life1 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
A helper function to log the response of an API request with context. Read more
impl Eq for LocalClient
impl StructuralPartialEq for LocalClient