pub enum RestClientError {
Show 17 variants
DiffError(DiffError),
MalformedEventInfo(String),
Request(Error),
RequestContext {
task: String,
source: Error,
},
Io {
task: String,
source: Error,
},
GitCommand(String),
RateLimitNoReset,
RateLimitPrimary(DateTime<Utc>),
RateLimitSecondary,
CannotCloneRequest,
InvalidHeaderValue(InvalidHeaderValue),
UnexpectedHeaderValue(ToStrError),
HeaderParseInt(ParseIntError),
UrlParse(ParseError),
Json {
task: String,
source: Error,
},
EnvVar {
name: String,
source: VarError,
},
OutputVar(OutputVariableError),
}Expand description
The possible error emitted by the REST client API
Variants
DiffError(DiffError)
file-changes only.Errors related to parsing git diffs.
MalformedEventInfo(String)
Error emitted when encountering malformed event information.
Request(Error)
Error related to making HTTP requests
RequestContext
Error related to making HTTP requests, with additional context about the request that caused the error.
Io
Errors related to standard I/O.
GitCommand(String)
file-changes only.Error related to git command execution.
RateLimitNoReset
Error related to exceeding REST API Rate limits and no reset time is provided in the response headers.
RateLimitPrimary(DateTime<Utc>)
Error related to exceeding REST API Rate limits with a known reset time.
RateLimitSecondary
Error related to exhausting all retries after hitting REST API Rate limits.
CannotCloneRequest
Error emitted when failing to clone a request object.
InvalidHeaderValue(InvalidHeaderValue)
Error emitted when failing to create a header value.
UnexpectedHeaderValue(ToStrError)
Error emitted when failing to convert a header value to string.
HeaderParseInt(ParseIntError)
Error emitted when failing to parse an integer from a header value (as a UTF-8 string).
UrlParse(ParseError)
Error emitted when failing to parse a URL.
Json
Error emitted when failing to deserialize/serialize request/response JSON data.
EnvVar
Error emitted when failing to read an environment variable.
Fields
OutputVar(OutputVariableError)
An error emitted when encountering an invalid OutputVariable.
Implementations
Sourceimpl RestClientError
impl RestClientError
Sourcepub fn env_var(name: &str, source: VarError) -> Self
pub fn env_var(name: &str, source: VarError) -> Self
Helper function to create an Self::EnvVar error with variable name and source error.
Sourcepub fn io(task: &str, source: Error) -> Self
pub fn io(task: &str, source: Error) -> Self
Helper function to create an Self::Io error with task context.
Sourcepub fn add_request_context(self, task: &str) -> Self
pub fn add_request_context(self, task: &str) -> Self
Builder function to add context to Self::Request errors.
Returns a Self::RequestContext error if self is a Self::Request error.
Otherwise, returns self unchanged.
Sourcepub fn json(task: &str, source: Error) -> Self
pub fn json(task: &str, source: Error) -> Self
Helper function to create a Self::Json error with task context.