pub struct DiffHunkHeader {
pub old_start: u32,
pub old_lines: u32,
pub new_start: u32,
pub new_lines: u32,
}Available on crate feature
file-changes only.Expand description
A struct to represent the header information of a diff hunk.
Fields
old_start: u32The starting line number of the old hunk.
old_lines: u32The total number of lines in the old hunk.
new_start: u32The starting line number of the new hunk.
new_lines: u32The total number of lines in the new hunk.