Module client

Module client 

A module to contain traits and structs that are needed by the rest of the git-bot-feedback crate’s API.

Structs

GithubApiClientgithub
A structure to work with Github REST API.
LocalClient
A (mostly) non-operational implementation of RestApiClient.
RestApiRateLimitHeaders
A structure to contain the different forms of headers that describe a REST API’s rate limit status.

Statics

USER_AGENT
The User-Agent header value included in all HTTP requests.

Traits

RestApiClient
A custom trait that templates necessary functionality with a Git server’s REST API.

Functions

init_client
Instantiate an implementation of RestApiClient based on the environment.