pub struct ReviewComment {
pub line_start: Option<u32>,
pub line_end: u32,
pub comment: String,
pub path: String,
}Expand description
A struct to describe a single comment in a Pull Request review.
Fields
line_start: Option<u32>The file’s line number in the diff that begins the the focus of the comment’s concerns.
line_end: u32The file’s line number in the diff that ends the focus of the comment’s concerns.
comment: StringThe actual comment.
This text can include a code block that demonstrates a suggested change(s).
Typically, the comment should not begin with the ReviewOptions::marker value.
That is managed by the git-bot-feedback library.
path: StringThe file that this comment pertains to.