pub struct ReviewOptions {
pub action: ReviewAction,
pub summary: String,
pub comments: Vec<ReviewComment>,
pub marker: String,
pub allow_draft: bool,
pub allow_closed: bool,
pub delete_review_comments: bool,
}Expand description
A struct to describe a Pull Request review.
Each review is considered to be about the PR event’s changes. There is no support for posting reviews on older/outdated PR events.
Fields
action: ReviewActionThe course of action that the PR review suggests.
summary: StringA summary of the PR review.
This is an overview of the review’s comments.
comments: Vec<ReviewComment>A list of comments for changes to the PR.
marker: StringA string used to mark/identify each comment (and Self::summary) as a
comment submitted by this software.
User comments may be indistinguishable from bot/generated comments if this value is not unique enough.
If the git server employs Markdown syntax for comments, then it is recommended to set this to an HTML comment that is unique to your CI application:
<!-- my-cool-CI-app-name -->The default value for this is an HTML comment generated from this crate’s name and version along with the compile-tome’s datetime. For example:
<!-- git-bot-feedback/0.1.0/Jul-14-2025_17-00 -->allow_draft: boolAllow posting reviews on draft Pull Requests?
allow_closed: boolAllow posting reviews on closed Pull Requests?
delete_review_comments: boolPermanently delete PR review outdated comments instead of hiding them.
Here be dragons!
Use with extreme caution when asserting this flag.
Setting this flag as true will permanently
delete PR review comments that may be pivotal to a thread of discussion.
Note, this does not apply to PR review summary comments nor threads of discussion within a review.